@@ -35,13 +35,6 @@
 
 #include "asterisk/inline_api.h"
 
-/* A time_t can be represented as an unsigned long long (or uint64_t).
- * Formatted in base 10, UINT64_MAX is 20 digits long, plus one for NUL.
- * This should be the size of the receiving char buffer for calls to
- * ast_time_t_to_string().
- */
-#define AST_TIME_T_LEN		21
-
 /* We have to let the compiler learn what types to use for the elements of a
    struct timeval since on linux, it's time_t and suseconds_t, but on *BSD,
    they are just a long.
@@ -115,7 +108,7 @@ int ast_tvzero(const struct timeval t),
 )
 
 /*!
- * \brief Compress two \c struct \c timeval instances returning
+ * \brief Compres two \c struct \c timeval instances returning
  * -1, 0, 1 if the first arg is smaller, equal or greater to the second.
  */
 AST_INLINE_API(
@@ -270,7 +263,7 @@ enum TIME_UNIT {
  * given string at least starts with one of the form values it will match.
  *
  * For example: us, usec, microsecond will all map to TIME_UNIT_MICROSECOND.
- * So will uss, usecs, microseconds, or even microsecondvals
+ * So will uss, usecs, miscroseconds, or even microsecondvals
  *
  * Matching is also not case sensitive.
  *
@@ -323,17 +316,4 @@ struct timeval ast_time_create_by_unit(unsigned long val, enum TIME_UNIT unit);
  */
 struct timeval ast_time_create_by_unit_str(unsigned long val, const char *unit);
 
-/*!
- * \brief Converts to a string representation of a time_t as decimal
- * seconds since the epoch. Returns -1 on failure, zero otherwise.
- *
- * The buffer should be at least 22 bytes long.
- */
-int ast_time_t_to_string(time_t time, char *buf, size_t length);
-
-/*!
- * \brief Returns a time_t from a string containing seconds since the epoch.
- */
-time_t ast_string_to_time_t(const char *str);
-
 #endif /* _ASTERISK_TIME_H */
